Installation
============

The queueing-tool module provides a framework for creating, simulating, and
visualizing queueing networks. The required packages are NetworkX and Numpy.
The network visualizations are handled by matplotlib, but is only required
for plotting. The package works with python versions 2.7 and 3.4-3.10.

The fastest was to install ``queueing-tool`` is with::

    $ pip install queueing_tool

You can obtain the development version of queueing-tool from it's
`github repository`_ using::

    $ pip install git+https://github.com/djordon/queueing-tool/zipball/master

.. _numpy docs: http://docs.scipy.org/doc/numpy/user/install.html
.. _networkx: http://networkx.readthedocs.org/en/stable/install.html
.. _github repository: https://github.com/djordon/queueing-tool
